package main

import (
	"fmt"
	"log"
	"os"
	"os/exec"
	"os/signal"
	"syscall"

	"github.com/gdamore/tcell"
	"github.com/rivo/tview"
)

func main() {
	// fim placeholder so we can operate on it when a signal is received
	var fim *exec.Cmd = nil

	// Setup signal listening
	sigs := make(chan os.Signal)
	signal.Notify(sigs, syscall.SIGINT, syscall.SIGTERM)
	defer func() { close(sigs) }()

	// Goroutine to handle os signals (nuke fim so we can get to config ui)
	go func() {
		for sig := range sigs {
			fmt.Println(sig)
			if fim != nil { // Just in case someone lays on ctrl-c or similar during startup
				if err := fim.Process.Kill(); err != nil {
					log.Fatal("failed to kill process: ", err)
				}
			}
		}
	}()

	// Forever run slideshow / show ui as the main program executed on a PiFrame
	for {
		// Run slideshow
		fim = exec.Command("/usr/local/bin/fim-slideshow.sh")
		if err := fim.Run(); err != nil {
			// Unwrap the error a bit so we can find out if a signal killed fim or something else
			// An exit code of -1 means the program didn't exit in time or was terminated by a signal (per the docs)
			if exitError, ok := err.(*exec.ExitError); ok && exitError.ExitCode() != -1 {
				log.Fatalf("Error : ", err)
			}
		}

		// Run config UI when slideshow stops
		app := tview.NewApplication()
		frame := tview.NewFrame(tview.NewBox().SetBackgroundColor(tcell.ColorBlack)).
			SetBorders(2, 2, 2, 2, 4, 4).
			AddText("PiFrame", true, tview.AlignCenter, tcell.ColorWhite).
			AddText("Configuration Utility", true, tview.AlignCenter, tcell.ColorRed)
		if err := app.SetRoot(frame, true).EnableMouse(true).Run(); err != nil {
			log.Fatal(err)
		}
	}
}
